import os

for module in os.listdir(os.path.dirname(__file__)):
    if module == '__init__.py' or module[-3:] != '.py':
        continue
    try:
        __import__(module[:-3], locals(), globals())
    except:
        print "frikin %s module is not working go check it out" % module

del module
del os



#!/usr/bin/env python

import pinv
import inspect


detected = []
run = []

for item, value in inspect.getmembers(pinv):

    if not item.startswith('__'):
        detected.append(item)
        if '__pinv__' in  dir(value):
            if value.__pinv__:
                run.append(value)

print "detected modules", detected

print "will run modules", [i.__name__ for i in run]

for i in run:
    i.main()


